@@ -875,8 +875,10 @@ SilcAccount::sendSilcCommand(const QString &command,
                              void *context)
 {
   if(! _conn) return;
+  if(! _client) return;
+
   kdDebug() << "SILCCommand: " << command.latin1() << endl;
-  assert(_client);
+
   SilcTK::SilcUInt16 cmd_ident = 
     SilcTK::silc_client_command_call(_client, _conn, command.latin1());
   if (reply)
@@ -941,14 +943,23 @@ SilcAccount::silc_connection_cb(SilcTK::SilcClient client,
     }
     account->updateAttributes();
 
+    // mark server window contact online
+    account->myServer()->setOnlineStatus
+      (SilcProtocol::protocol()->statusOnline);
+
     // emit connected signal ...
     emit account->connected();
     break;
+
   case SilcTK::SILC_CLIENT_CONN_DISCONNECTED:
     kdDebug() << "client: disconnected" << endl;
     account->_conn = 0;
     account->setOnlineStatus(SilcProtocol::protocol()->statusOffline);
 
+    // mark server window contact offline
+    account->myServer()->setOnlineStatus
+      (SilcProtocol::protocol()->statusOffline);
+
     emit account->disconnected();
 
     if(error)
@@ -977,6 +988,7 @@ display_error:
        i18n("Unable to establish connection to the remote host: %1")
        .arg(error_msg), i18n("Kopete SilcTK::SILC Plugin"));
     account->_conn = 0;
+    account->setOnlineStatus(SilcProtocol::protocol()->statusOffline);
     break;
   }
 }
